==> jc-1.4.0.tar.gz: gnu/xml/dom/DomXPathNSResolver.h <==
// class gnu.xml.dom.DomXPathNSResolver

// class file dependencies
// @dep_class bd5a917d4e832fc2 gnu_xml_dom_DomXPathNSResolver
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomXPathNSResolver_H_
#define _JC_gnu_xml_dom_DomXPathNSResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_refs	_jc_gnu_xml_dom_DomXPathNSResolver$sub_refs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs	_jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$refs	_jc_gnu_xml_dom_DomXPathNSResolver$refs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$nonrefs	_jc_gnu_xml_dom_DomXPathNSResolver$nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$object	_jc_gnu_xml_dom_DomXPathNSResolver$object;

typedef const struct _jc_gnu_xml_dom_DomXPathNSResolver$vmethods	_jc_gnu_xml_dom_DomXPathNSResolver$vmethods;
typedef const struct _jc_gnu_xml_dom_DomXPathNSResolver$vtable	_jc_gnu_xml_dom_DomXPathNSResolver$vtable;
typedef const struct _jc_gnu_xml_dom_DomXPathNSResolver$vtype	_jc_gnu_xml_dom_DomXPathNSResolver$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomXPathNSResolver$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_gnu_xml_dom_DomXPathNSResolver$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2(_jc_env *, struct _jc_gnu_xml_dom_DomXPathNSResolver$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomXPathNSResolver$vmethods {
	struct _jc_java_lang_String$object	*(*lookupNamespaceURI$14d569e8938f97a2)(_jc_env *, struct _jc_gnu_xml_dom_DomXPathNSResolver$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_gnu_xml_dom_DomXPathNSResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomXPathNSResolver$vmethods	gnu_xml_dom_DomXPathNSResolver;
};

// Vtype
struct _jc_gnu_xml_dom_DomXPathNSResolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomXPathNSResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathNSResolver$refs {
    _jc_gnu_xml_dom_DomXPathNSResolver$sub_refs	gnu_xml_dom_DomXPathNSResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathNSResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs	gnu_xml_dom_DomXPathNSResolver;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomXPathNSResolver$object {
	_jc_gnu_xml_dom_DomXPathNSResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomXPathNSResolver$vtype	*vtype;
	_jc_gnu_xml_dom_DomXPathNSResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomXPathNSResolver$vtype _jc_gnu_xml_dom_DomXPathNSResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomXPathNSResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomXPathNSResolver$class_object;

#endif	/* _JC_gnu_xml_dom_DomXPathNSResolver_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/dom/DomXPathNSResolver.h <==
// class gnu.xml.dom.DomXPathNSResolver

// class file dependencies
// @dep_class bd5a917d4e832fc2 gnu_xml_dom_DomXPathNSResolver
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_xml_dom_DomXPathNSResolver_H_
#define _JC_gnu_xml_dom_DomXPathNSResolver_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_refs	_jc_gnu_xml_dom_DomXPathNSResolver$sub_refs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs	_jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$refs	_jc_gnu_xml_dom_DomXPathNSResolver$refs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$nonrefs	_jc_gnu_xml_dom_DomXPathNSResolver$nonrefs;
typedef struct _jc_gnu_xml_dom_DomXPathNSResolver$object	_jc_gnu_xml_dom_DomXPathNSResolver$object;

typedef const struct _jc_gnu_xml_dom_DomXPathNSResolver$vmethods	_jc_gnu_xml_dom_DomXPathNSResolver$vmethods;
typedef const struct _jc_gnu_xml_dom_DomXPathNSResolver$vtable	_jc_gnu_xml_dom_DomXPathNSResolver$vtable;
typedef const struct _jc_gnu_xml_dom_DomXPathNSResolver$vtype	_jc_gnu_xml_dom_DomXPathNSResolver$vtype;

// Constructors
extern void _jc_gnu_xml_dom_DomXPathNSResolver$method$_init$ea4cfa151ae11b7c(_jc_env *, struct _jc_gnu_xml_dom_DomXPathNSResolver$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_gnu_xml_dom_DomXPathNSResolver$method$lookupNamespaceURI$14d569e8938f97a2(_jc_env *, struct _jc_gnu_xml_dom_DomXPathNSResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_dom_DomXPathNSResolver$method_info$lookupNamespaceURI$14d569e8938f97a2;

// Virtual methods structure
struct _jc_gnu_xml_dom_DomXPathNSResolver$vmethods {
	struct _jc_java_lang_String$object	*(*lookupNamespaceURI$14d569e8938f97a2)(_jc_env *, struct _jc_gnu_xml_dom_DomXPathNSResolver$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_dom_DomXPathNSResolver$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_dom_DomXPathNSResolver$vmethods	gnu_xml_dom_DomXPathNSResolver;
};

// Vtype
struct _jc_gnu_xml_dom_DomXPathNSResolver$vtype {
	_jc_type			type;
	_jc_gnu_xml_dom_DomXPathNSResolver$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_refs {
	struct _jc_object	*node;
};

// Reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathNSResolver$refs {
    _jc_gnu_xml_dom_DomXPathNSResolver$sub_refs	gnu_xml_dom_DomXPathNSResolver;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_dom_DomXPathNSResolver$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_dom_DomXPathNSResolver$sub_nonrefs	gnu_xml_dom_DomXPathNSResolver;
};

// Object instance structure
struct _jc_gnu_xml_dom_DomXPathNSResolver$object {
	_jc_gnu_xml_dom_DomXPathNSResolver$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_dom_DomXPathNSResolver$vtype	*vtype;
	_jc_gnu_xml_dom_DomXPathNSResolver$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_dom_DomXPathNSResolver$vtype _jc_gnu_xml_dom_DomXPathNSResolver$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_dom_DomXPathNSResolver, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_dom_DomXPathNSResolver$class_object;

#endif	/* _JC_gnu_xml_dom_DomXPathNSResolver_H_ */
